@@ -146,7 +146,7 @@ data_plot.p_direction <- function(x, data = NULL, show_intercept = FALSE, ...) {
 #' @inheritParams data_plot
 #' @inheritParams plot.see_bayesfactor_parameters
 #' @inheritParams plot.see_estimate_density
-#' @inheritParams plot.see_cluster_analysis
+#' @inheritParams plot.see_parameters_model
 #'
 #' @return A ggplot2-object.
 #'
@@ -159,7 +159,7 @@ data_plot.p_direction <- function(x, data = NULL, show_intercept = FALSE, ...) {
 #'   plot(result)
 #' }
 #' }
-#' @importFrom rlang .data
+#' @importFrom ggplot2 .data
 #' @export
 plot.see_p_direction <- function(x,
                                  data = NULL,
@@ -186,6 +186,8 @@ plot.see_p_direction <- function(x,
   # get labels
   labels <- .clean_parameter_names(x$y, grid = !is.null(n_columns))
 
+  insight::check_if_installed("ggridges")
+
   # base setup
   p <- ggplot(
     as.data.frame(x),
