@@ -1,6 +1,12 @@
 if (require("testthat")) {
   library(see)
 
+  if (length(strsplit(packageDescription("see")$Version, "\\.")[[1]]) > 3) {
+    Sys.setenv("RunAllseeTests" = "yes")
+  } else {
+    Sys.setenv("RunAllseeTests" = "no")
+  }
+
   osx <- tryCatch(
     {
       si <- Sys.info()
