@@ -3,7 +3,7 @@ if (getRversion() >= "4.1" && getRversion() < "4.2" &&
   require("ggplot2") &&
   require("bayestestR")) {
   test_that("bayestestR package plots rendered correctly", {
-    skip_on_cran()
+    skip_if_not(.Platform$OS.type == "windows")
 
     # plot.see_bayesfactor_models() --------------------
 
